import { RcSdk } from "./RcSdk";

interface IUserCreate {
    email: string;
    name: string;
    password: string;
    username: string;
    active?: boolean;
    roles?: Array<string>;
    joinDefaultChannels?: boolean;
    requirePasswordChange?: boolean;
    sendWelcomeEmail?: boolean;
    verified?: boolean;
    customFields?: any;
}

interface IUserUpdate {
    userId: string;
    data: {
        email?: string;
        name?: string;
        password?: string;
        username?: string;
        active?: boolean;
        roles?: Array<string>;
        joinDefaultChannels?: boolean;
        requirePasswordChange?: boolean;
        sendWelcomeEmail?: boolean;
        verified?: boolean;
        customFields?: any;
    };
}

interface IUserDelete {
    userId: string;
    confirmRelinquish?: boolean;
}

export interface IUser {
    _id: string;
    emails: Array<{ address: string; verified: boolean }>;
    name: string;
    username: string;
    active?: boolean;
    createdAt: string;
    _updatedAt?: string;
}

interface IUserListResponse {
    users: Array<IUser>;
    count: number;
    offset: number;
    total: number;
    success: boolean;
    error?: string;
}

interface IUserResponse {
    user: IUser;
    success: boolean;
    error?: string;
}

interface IUserDeleteResponse {
    success: boolean;
    error?: string;
}

export class RcSdkUser {
    private sdk: RcSdk;
    constructor(sdk: RcSdk) {
        this.sdk = sdk;
    }

    public list(): Promise<IUserListResponse> {
        return this.sdk.get(
            `users.list?query={"type":{"$eq":"user"}}&fields={"createdAt":1}`,
        );
    }

    public info(userId: string): Promise<IUserResponse> {
        return this.sdk.get(`users.info?userId=${userId}`);
    }

    public update(body: IUserUpdate): Promise<IUserResponse> {
        return this.sdk.post(`users.update`, body);
    }

    public delete(body: IUserDelete): Promise<IUserDeleteResponse> {
        return this.sdk.post(`users.delete`, body);
    }

    public create(body: IUserCreate): Promise<IUserResponse> {
        return this.sdk.post(`users.create`, body);
    }
}
